# neclib

[![PyPI](https://img.shields.io/pypi/v/neclib.svg?label=PyPI&style=flat-square)](https://pypi.org/pypi/neclib/)
[![Python](https://img.shields.io/pypi/pyversions/neclib.svg?label=Python&color=yellow&style=flat-square)](https://pypi.org/pypi/neclib/)
[![Test](https://img.shields.io/github/workflow/status/nanten2/neclib/Test?logo=github&label=Test&style=flat-square)](https://github.com/nanten2/neclib/actions)
[![License](https://img.shields.io/badge/license-MIT-blue.svg?label=License&style=flat-square)](LICENSE)

Pure Python tools for NECST.

## Features

This library provides:

- Miscellaneous tools for NECST system.

## Installation

```shell
pip install neclib
```

## Usage

See the [API reference](https://nanten2.github.io/neclib/_source/neclib.html).

---

This library is using [Semantic Versioning](https://semver.org).
